@@ -15,19 +15,26 @@ FILE_SAFE_CHARACTERS = (u' '
                         u'abcdefghijklmnopqrstuvwxyz'
                         u'ABCDEFGHIJKLMNOPQRSTUVWXYZ')
 
+FOLDER_SAFE_CHARACTERS = (u'1234567890-_'
+                          u'abcdefghijklmnopqrstuvwxyz'
+                          u'ABCDEFGHIJKLMNOPQRSTUVWXYZ')
+
 
 def file_safe(string,
-              safe_char=u'_'):
-    return u''.join([c if c in FILE_SAFE_CHARACTERS
+              safe_char=u'_',
+              safe_chars=FILE_SAFE_CHARACTERS):
+    return u''.join([c if c in safe_chars
                      else safe_char
                      for c in string])
 
 
 def file_safe_path(path,
-                   safe_char=u'_'):
+                   safe_char=u'_',
+                   safe_chars=FILE_SAFE_CHARACTERS):
     drive, path = os.path.splitdrive(path)
     path_parts = [file_safe(string=part,
-                            safe_char=safe_char)
+                            safe_char=safe_char,
+                            safe_chars=safe_chars)
                   for part in path.replace(u'\\', u'/').split(u'/')]
 
     return drive + os.sep.join(path_parts)
