@@ -1,6 +1,9 @@
 # encoding: utf-8
 
-from collections import Mapping
+try:
+    from collections.abc import Mapping
+except ImportError:
+    from collections import Mapping
 
 
 def is_dictionary(item):
